Aglyph 2.0.0 testing summary — Aglyph 3.0.0 documentation

# Aglyph 2.0.0 testing summary

Warning

Changed in version 2.0.0.

The Python 2.5 lifespan has ended; the Aglyph test suite is no longer executed under this version.

Note

Prior to each Aglyph release being committed, tagged, and packaged, its test suite is executed on several Python implementations, versions, and platforms.

When a Python version reaches end-of-life, the Aglyph test suite is no longer “officially” executed against that version. This does not necessarily imply that Aglyph unit tests fail under that Python version; it simply means that I no longer publish or withhold a release based on the test suite results from that particular Python version.

## CPython

Version | Platform
--- | ---
2.6.6 | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit (Intel)
2.6.9 | Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5666) (dot 3)
2.7.6 | Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5666) (dot 3)
| Windows-7-6.1.7601-SP1 MSC v.1500 32 bit (Intel)
3.1.4 | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit (Intel)
3.1.5 | Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5646) (dot 1)
3.2.5 | Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5666) (dot 3)
| Windows-7-6.1.7601-SP1 MSC v.1500 32 bit (Intel)
3.3.3 | Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5666) (dot 3)
| Windows-7-6.1.7601-SP1 MSC v.1600 32 bit (Intel)

## PyPy

Version | Platform
--- | ---
2.2.1 | CPython 2.7.3 Darwin-10.8.0-i386-64bit
| CPython 2.7.3 Windows-7-6.1.7601-SP1

## Stackless Python

Version | Platform
--- | ---
3.1b3 | CPython 2.7.5 Stackless 3.1b3 060516 (default, Jan 5 2014, 23:58:02)
| CPython 2.7.5 Stackless 3.1b3 060516 (default, May 21 2013, 17:59:42) [MSC v.1500 32 bit (Intel)] Windows-7-6.1.7601-SP1
| CPython 3.2.2 Stackless 3.1b3 060516 (default, Mar 20 2013, 23:10:27)
| CPython 3.2.2 Stackless 3.1b3 060516 (default, Feb 20 2012, 13:36:12) [MSC v.1500 32 bit (Intel)] Windows-7-6.1.7601-SP1

## IronPython

Version | Platform
--- | ---
2.7.4 | Windows-7-6.1.7601-SP1 cli-32bit .NET 4.0.30319.1008 (32-bit)

## Jython

Version | Platform
--- | ---
2.5.3 | Java-1.6.0_65-Java_HotSpot-TM-_64-Bit_Server_VM,_20.65-b04-462,_Apple_Inc.-on-Mac_OS_X-10.6.8-x86_64 Java HotSpot(TM) 64-Bit Server VM (Apple Inc.)
| Java-1.7.0_17-Java_HotSpot-TM-_Client_VM,_23.7-b01,_Oracle_Corporation-on-Windows_7-6.1-x86 Java HotSpot(TM) Client VM (Oracle Corporation)